@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# Application Name - Health Check V0.5.0-3
+# Application Name - Health Check V0.5.0-4
 # Date 17 February 2010
 # Author - Greg Roberts (Noobmonkey @ Maemo Talk)
 # Contact - Me@Greg-roberts.com
@@ -359,7 +359,7 @@ class Ui_MainWindow(object):
         # box of some sort
         self.textBrowser = QtGui.QTextBrowser(self.tab_5)
         self.textBrowser.setGeometry(QtCore.QRect(0, 10, 781, 301))
-        self.textBrowser.setText (" Health Check V 0.5.0-3 \n Greg Roberts (Maemo.org - Noobmonkey) \n me@greg-roberts.com \n \n For Bugs and Feature requests: \n http://talk.maemo.org/showthread.php?p=541457")
+        self.textBrowser.setText (" Health Check V 0.5.0-4 \n Greg Roberts (Maemo.org - Noobmonkey) \n me@greg-roberts.com \n \n For Bugs and Feature requests: \n http://talk.maemo.org/showthread.php?p=541457")
         # Make the font small!!!
         font = QtGui.QFont()
         font.setPointSize(20)
@@ -456,9 +456,12 @@ class Ui_MainWindow(object):
         # This one reads the applications list from dpkg
         # Do some string functions to find/remove messy parts of the battery pulled text.
         # Please excuse the poorly labeled variables here!
-        C_a = str(bg)[:-14]
+        C_a = str(bg)[:-15]
+        print C_a
         C_b = str(C_a)[-4:]
+        print C_b
         barxval = str.strip(C_b)
+        print barxval
         self.lbl_Battery_Bar.setRange(0,100)
         self.lbl_Battery_Bar.setProperty("value", barxval)
 
@@ -486,9 +489,9 @@ class Ui_MainWindow(object):
         ge = os.popen('df -h /home/user/MyDocs').read()
         # Remove some of the faffy bits. I've left the total free and percentage used at the moment, is a little confusing
         gf = str(ge)[-34:]
-        print gf
+        
         gf = gf[:-24]
-        print gf
+        
         self.lbl_mydocsd_info.setText(gf.strip())
         
 # Funtion - update tab.... Originally to update tab1, but using it to collate the functions
@@ -534,7 +537,7 @@ class Ui_MainWindow(object):
         
     # This is the start of the QT Designer translation function - not using the translation function, but left it in, to show it is part of the class   
     def retranslateUi(self, MainWindow):
-        MainWindow.setWindowTitle(QtGui.QApplication.translate("MainWindow", "Health Check 0.5.0-3", None, QtGui.QApplication.UnicodeUTF8))
+        MainWindow.setWindowTitle(QtGui.QApplication.translate("MainWindow", "Health Check 0.5.0-4", None, QtGui.QApplication.UnicodeUTF8))
         self.tabWidget.setTabText(self.tabWidget.indexOf(self.tab), QtGui.QApplication.translate("MainWindow", "System", None, QtGui.QApplication.UnicodeUTF8))
         self.tabWidget.setTabText(self.tabWidget.indexOf(self.tab_2), QtGui.QApplication.translate("MainWindow", "Comms", None, QtGui.QApplication.UnicodeUTF8))
         self.tabWidget.setTabText(self.tabWidget.indexOf(self.tab_3), QtGui.QApplication.translate("MainWindow", "Camera", None, QtGui.QApplication.UnicodeUTF8))
